<?php

namespace Drupal\sparkpost;

use Drupal\Core\Config\ConfigFactory;
use GuzzleHttp\Client;
use SparkPost\SparkPost;
use Http\Adapter\Guzzle6\Client as GuzzleAdapter;

/**
 * Class ClientService.
 *
 * @package Drupal\sparkpost
 */
class ClientService implements ClientServiceInterface {

  /**
   * Drupal\Core\Config\ConfigFactory definition.
   *
   * @var ConfigFactory
   */
  protected $configFactory;

  /**
   * GuzzleHttp\Client definition.
   *
   * @var Client
   */
  protected $client;

  /**
   * Constructor.
   */
  public function __construct(Client $client, ConfigFactory $configFactory) {
    $this->client = $client;
    $this->configFactory = $configFactory;
  }

  /**
   * @return \SparkPost\SparkPost
   */
  public function getClient() {
    $config = $this->configFactory->get('sparkpost.settings');
    $httpClient = new GuzzleAdapter($this->client);
    return new SparkPost($httpClient, ['key' => $config->get('api_key')]);
  }

  /**
   * @param array $message
   * @return array
   * @throws \SparkPost\SparkPostException
   */
  public function sendMessage(array $message) {
    $config = $this->configFactory->get('sparkpost.settings');
    $client = $this->getClient();
    $message['content']['from'] = [
      'name' => $config->get('sender_name'),
      'email' => $config->get('sender'),
    ];
    $promise = $client->transmissions->post($message);
    $response = $promise->wait();
    return $response->getBody();
  }

  /**
   * @param string $endpoint
   * @param array $data
   * @param string $method
   * @return array
   * @throws \SparkPost\SparkPostException
   */
  public function sendRequest($endpoint, array $data, $method = 'GET') {
    $client = $this->getClient();
    $promise = $client->request($method, $endpoint, $data);
    $response = $promise->wait();
    return $response->getBody();
  }

}
